declare enum Day {
    Sunday = 0,
    Monday = 1,
    Tuesday = 2,
    Wednesday = 3,
    Thursday = 4,
    Friday = 5,
    Saturday = 6
}
declare class CronGenerator {
    /**
     * The cron expression
     */
    private expression;
    /**
     * Insert the given value into the given position
     */
    private spliceIntoPosition;
    /**
     * Returns the built cron expression
     */
    get(): string;
    /**
     * Schedule with a custom cron expression
     */
    private cron;
    /**
     * Schedule to run every minute
     */
    everyMinute(): this;
    /**
     * Schedule to run every two minutes
     */
    everyTwoMinutes(): this;
    /**
     * Schedule to run every five minutes
     */
    everyFiveMinutes(): this;
    /**
     * Schedule to run every ten minutes
     */
    everyTenMinutes(): this;
    /**
     * Schedule to run every fifteen minutes
     */
    everyFifteenMinutes(): this;
    /**
     * Schedule to run every thirty minutes
     */
    everyThirtyMinutes(): this;
    /**
     * Schedule to run x minutes
     */
    everyXMinutes(minutes: number): this;
    /**
     * Schedule to run every hour
     */
    everyHour(): this;
    /**
     * Schedule to run every two hours
     */
    everyTwoHours(): this;
    /**
     * Schedule to run every three hours
     */
    everyThreeHours(): this;
    /**
     * Schedule to run every six hours
     */
    everySixHours(): this;
    /**
     * Schedule to run every twelves hours
     */
    everyTwelveHours(): this;
    /**
     * Schedule to run every x hours
     */
    everyXHours(hours: number): this;
    /**
     * Schedule to run daily
     */
    daily(): this;
    /**
     * Set the days of the week the command should run on
     */
    days(days: Day[] | Day | string): this;
    /**
     * Schedule to run only on weekdays
     */
    weekdays(): this;
    /**
     * Schedule to run only on weekends
     */
    weekends(): this;
    /**
     * Schedule to run only on mondays
     */
    mondays(): this;
    /**
     * Schedule to run only on Tuesdays
     */
    tuesdays(): this;
    /**
     * Schedule to run only on Wednesdays
     */
    wednesdays(): this;
    /**
     * Schedule to run only on thursdays
     */
    thursdays(): this;
    /**
     * Schedule to run only on fridays
     */
    fridays(): this;
    /**
     * Schedule to run only on Saturdays
     */
    saturdays(): this;
    /**
     * Schedule to run only on Sundays
     */
    sundays(): this;
    /**
     * Schedule to run weekly
     */
    weekly(): this;
    /**
     * Schedule at the given time
     */
    at(time: string): this;
    /**
     * Schedule to run daily at the given time
     */
    dailyAt(time: string): this;
    /**
     * Schedule to run weekly on q given day and time
     */
    weeklyOn(day: Day, time: string): this;
    /**
     * Schedule to run monthly
     */
    monthly(): this;
    /**
     * Schedule to run monthly on the given day and time
     */
    monthlyOn(day: Day, time: string): this;
    /**
     * Schedule to run quarterly
     */
    quarterly(): this;
    /**
     * Schedule to run yearly.
     */
    yearly(): this;
    /**
     * Schedule to run yearly on the given day and time
     */
    yearlyOn(month?: number, dayOfMonth?: string | number, time?: string): this;
}

declare function cron(): CronGenerator;

export { Day, cron };
